<?php

/*
 * LMS version 1.8.12 Tagan
 *
 *  (C) Copyright 2001-2006 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: checkconfig.php,v 1.2.2.3 2006/06/11 09:37:43 alec Exp $
 */

function chkconfig($value, $default = FALSE)
{
	if(!isset($value) || $value == '')
		return $default;
	elseif(eregi('^(1|y|on|yes|true|tak|t)$', $value))
		return TRUE;
	elseif(eregi('^(0|n|no|off|false|nie)$', $value))
		return FALSE;
	else
		trigger_error('Incorrect option value: '.$value);
}

?>
